@@ -3,6 +3,8 @@ package DayDayUp::Notes;
 use strict;
 use warnings;
 
+our $VERSION = '0.02';
+
 use base 'Mojolicious::Controller';
 
 use Data::Dumper;
@@ -157,9 +159,15 @@ sub update {
     	}
     }
     
-    my $sql = q~UPDATE notes SET status = ? WHERE note_id = ?~;
-    my $sth = $dbh->prepare($sql);
-    $sth->execute( $st_val, $id );
+    if ( $status eq 'closed' ) {
+    	my $sql = q~UPDATE notes SET status = ?, closed_time = ? WHERE note_id = ?~;
+		my $sth = $dbh->prepare($sql);
+		$sth->execute( $st_val, time(), $id );
+    } else {
+		my $sql = q~UPDATE notes SET status = ? WHERE note_id = ?~;
+		my $sth = $dbh->prepare($sql);
+		$sth->execute( $st_val, $id );
+    }
     
     $c->render(template => 'redirect.html', url => '/notes/');
 }
